Crate ligen_common

Crate ligen_common 

Re-exports

pub use serde;
pub use error::*;

Modules

error
Error types.

Traits

Deserialize
A data structure that can be deserialized from any data format supported by Serde.
Serialize
A data structure that can be serialized into any data format supported by Serde.
TryFrom
Simple and safe type conversions that may fail in a controlled way under some circumstances. It is the reciprocal of TryInto.
TryInto
An attempted conversion that consumes self, which may or may not be expensive.

Derive Macros

Deserialize
Serialize
Shrinkwrap