Crate ligen_common
Source pub use serde;pub use error::*;
- error
- Error types.
- Deserialize
- A data structure that can be deserialized from any data format supported
by Serde.
- Serialize
- A data structure that can be serialized into any data format supported
by Serde.
- TryFrom
- Simple and safe type conversions that may fail in a controlled
way under some circumstances. It is the reciprocal of
TryInto. - TryInto
- An attempted conversion that consumes
self, which may or may not be
expensive.
- Deserialize
- Serialize
- Shrinkwrap